@@ -21,7 +21,11 @@ pub struct Duration {
 
 pub trait DurationExtractor {
     fn supports_ext(&self, ext_lowercase: &str) -> bool;
-    fn try_read_duration(&self, path: &Path, mp3_metadata: &Option<MP3Metadata>) -> io::Result<Option<Duration>>;
+    fn try_read_duration(
+        &self,
+        path: &Path,
+        mp3_metadata: &Option<MP3Metadata>,
+    ) -> io::Result<Option<Duration>>;
 }
 
 const EXTRACTORS: [&dyn DurationExtractor; 4] = [
@@ -31,11 +35,19 @@ const EXTRACTORS: [&dyn DurationExtractor; 4] = [
     &WavDurationExtractor,
 ];
 
-pub fn get_duration<T: AsRef<Path>>(path: T, mp3_metadata: &Option<MP3Metadata>) -> Option<Duration> {
+pub fn get_duration<T: AsRef<Path>>(
+    path: T,
+    mp3_metadata: &Option<MP3Metadata>,
+) -> Option<Duration> {
     let path_ref = path.as_ref();
     let extension = path_ref.extension()?.to_str()?;
 
-    EXTRACTORS.iter()
+    EXTRACTORS
+        .iter()
         .find(|extractor| extractor.supports_ext(&extension.to_lowercase()))
-        .and_then(|extractor| extractor.try_read_duration(path_ref, mp3_metadata).unwrap_or_default())
-}
\ No newline at end of file
+        .and_then(|extractor| {
+            extractor
+                .try_read_duration(path_ref, mp3_metadata)
+                .unwrap_or_default()
+        })
+}
